[systemd-commits] src/modules-load.c

Kay Sievers kay at kemper.freedesktop.org
Tue Sep 28 08:03:26 PDT 2010


 src/modules-load.c |    8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

New commits:
commit 15917fb09b669021d1f20ddc1f468d156b05a8e0
Author: Kay Sievers <kay.sievers at vrfy.org>
Date:   Tue Sep 28 17:02:29 2010 +0200

    modules-load: use /etc/modules-load.d/?*.conf

diff --git a/src/modules-load.c b/src/modules-load.c
index 56f2a90..a1738bb 100644
--- a/src/modules-load.c
+++ b/src/modules-load.c
@@ -31,7 +31,7 @@
 #include "util.h"
 #include "strv.h"
 
 /* This reads all module names listed in /etc/modules.d/?*.conf and
  * loads them into the kernel. This follows roughly Debian's way to
  * handle modules, but uses a directory of fragments instead of a
  * single /etc/modules file. */
@@ -71,12 +71,12 @@ int main(int argc, char *argv[]) {
 
         n_arguments = n_allocated = 3;
 
-        if ((n = scandir("/etc/modules.d/", &de, scandir_filter, alphasort)) < 0) {
+        if ((n = scandir("/etc/modules-load.d/", &de, scandir_filter, alphasort)) < 0) {
 
                 if (errno == ENOENT)
                         r = EXIT_SUCCESS;
                 else
-                        log_error("Failed to enumerate /etc/modules.d/ files: %m");
+                        log_error("Failed to enumerate /etc/modules-load.d/ files: %m");
 
                 goto finish;
         }
@@ -88,7 +88,7 @@ int main(int argc, char *argv[]) {
                 char *fn;
                 FILE *f;
 
-                k = asprintf(&fn, "/etc/modules.d/%s", de[i]->d_name);
+                k = asprintf(&fn, "/etc/modules-load.d/%s", de[i]->d_name);
                 free(de[i]);
 
                 if (k < 0) {
@@ -31,7 +31,7 @@
 #include "strv.h"
 
-/* This reads all module names listed in /etc/modules.d/?*.conf and
+/* This reads all module names listed in /etc/modules-load.d/?*.conf and
  * loads them into the kernel. This follows roughly Debian's way to
  * handle modules, but uses a directory of fragments instead of a


More information about the systemd-commits mailing list